/* dupsd  (Dumb UPS monitor Daemon)
 * Copyright (C) 1998 Malinin A. G.
 *
 * This  program  is free software;  you can redistribute it  and/or
 * modify  it  under  the  terms of the  GNU  General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed  in the hope that  it will be useful,
 * but  WITHOUT ANY WARRANTY;   without even the implied warranty of
 * MERCHANTABILITY  or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along  with  this  program;  if not,  write to the  Free Software
 * Foundation,  Inc.,   59  Temple  Place,  Suite  330,  Boston,  MA
 * 02111-1307  USA.

 * Author's E-mail address: mag@h26.216.elnet.msk.ru.
 */

/* dups.h */


#define ON 			1
#define OFF	 		0
#define UNKNOWN			-1

/* DUPS state codes */
#define unknown_DUPS_state	-1
#define DUPS_OK			0
#define DUPS_on_battery		1
#define low_DUPS_battery	2
#define DUPS_error		3

/* DUPS control codes */
#define monitor_ready		4
#define shutdown_DUPS		5

/* DUPS logic codes */
#define USUAL 			1
#define INVERSE 		0
#define UNDEFINED		-1

/*
  example:
	let the UPS "on battery" state is when DCD wire changes
	from logical "1" to "0", then:
	struct line_descr line_descr_item={TIOCM_DCD, INVERSE};

	let the UPS "on battery" state is when DCD wire changes
	from logical "0" to "1", then:
	struct line_descr line_descr_item={TIOCM_DCD, USUAL};

	let the UPS DCD wire is not used then:
	struct line_descr line_descr_item={TIOCM_DCD, UNDEFINED};
*/
struct line_descr {
  int line;				/* TIOCM_DTR, ... */
  int logic;				/* USUAL or INVERSE or UNDEFINED */
};

typedef struct line_descr LINE_DESCR;

/* internal DUPS operation description */
extern LINE_DESCR ld[shutdown_DUPS+1];

/* delay for "turn the UPS off" command in seconds */
extern unsigned int shutdown_delay;


/*
  opens the device "device", which should be a serial port
  that communicates with the UPS; returns a file descriptor;
  if open fails, writes a log message and returns -1
*/
int
open_DUPS(const char *device);

/*
  initializes the UPS on previously opened device with descriptor "fd"
*/
void
setup_DUPS(int fd);

/*
  turns the UPS (on previously opened device with descriptor "fd") off
*/
void
kill_DUPS_power(int fd);

/*
  returns the UPS (on previously opened device with descriptor "fd") state
  (DUPS_error|low_DUPS_battery|DUPS_on_battery|DUPS_OK)
*/
int
check_DUPS(int fd);
